@@ -9,8 +9,8 @@ from typing import Callable, Optional
 
 from iotas.backup_manager import BackupManager
 import iotas.const as const
-import iotas.config_manager
-from iotas.database import Database
+from iotas.config_manager import ConfigManager
+from iotas.database import Database, DbCursor
 from iotas.migration_assistant import MigrationAssistant
 from iotas.note_database import NoteDatabase
 from iotas.preferences_dialog import PreferencesDialog
@@ -42,6 +42,9 @@ class Application(Adw.Application):
             register_session=True,
         )
 
+        ConfigManager.set_app_id(const.APP_ID)
+        self.__config_manager = ConfigManager.get_default()
+
         self.__add_cli_options()
 
         self.__base_css_resource = "{}/ui/base_style.css".format(self.props.resource_base_path)
@@ -58,6 +61,7 @@ class Application(Adw.Application):
         style_manager.connect("notify::dark", lambda _o, _v: self.__apply_css())
         style_manager.connect("notify::high-contrast", lambda _o, _v: self.__apply_css())
 
+        self.cursors: dict[str, DbCursor] = {}
         self.__actions: dict[str, Gio.SimpleAction] = {}
         self.__window: Optional[Adw.ApplicationWindow] = None
         self.__preferences_dialog: Optional[PreferencesDialog] = None
@@ -67,19 +71,20 @@ class Application(Adw.Application):
         self.connect("activate", lambda _o: self.__on_activate())
         self.connect("handle-local-options", self.__on_handle_local_options)
 
-        iotas.config_manager.settings.connect(
-            f"changed::{iotas.config_manager.INDEX_CATEGORY_STYLE}",
-            lambda _o, _k: self.__apply_index_category_label_css(),
+        self.__config_manager.connect_changed(
+            ConfigManager.INDEX_CATEGORY_STYLE,
+            self.__apply_index_category_label_css,
         )
 
     def disconnect_nextcloud(self) -> None:
         """Disconnect from Nextcloud instance and exit."""
         if not self.__sync_manager.authenticated:
             return
+        assert self.__window  # mypy
 
         self.__sync_manager.sign_out()
         self.db.delete_all_clean_synced_notes()
-        iotas.config_manager.set_nextcloud_username("")
+        self.__config_manager.nextcloud_username = ""
         self.__window.close()
 
     def do_open(self, files: list[Gio.File], n_files: int, _hint: str) -> None:
@@ -109,9 +114,20 @@ class Application(Adw.Application):
     def reset_database(self) -> None:
         """Destroy the database and quit."""
         self.db_base.trash()
-        iotas.config_manager.set_nextcloud_prune_threshold(0)
+        self.__config_manager.nextcloud_prune_threshold = 0
         self.quit()
 
+    def apply_style(self) -> None:
+        """Apply style preference."""
+        manager = Adw.StyleManager.get_default()
+        style = self.__config_manager.style
+        if style == "dark":
+            manager.props.color_scheme = Adw.ColorScheme.FORCE_DARK
+        elif style == "light":
+            manager.props.color_scheme = Adw.ColorScheme.FORCE_LIGHT
+        else:
+            manager.props.color_scheme = Adw.ColorScheme.DEFAULT
+
     @GObject.Property(type=bool, default=False)
     def debug_session(self) -> bool:
         return self.__debug_session
@@ -134,7 +150,7 @@ class Application(Adw.Application):
         self.__sync_manager = SyncManager(self.db)
         self.__backup_manager = BackupManager(self.db, const.VERSION)
 
-        self.previous_version = iotas.config_manager.get_last_launched_version()
+        self.previous_version = self.__config_manager.last_launched_version
         migration_assistant = MigrationAssistant(self.db)
         migration_assistant.migrate()
 
@@ -182,8 +198,8 @@ class Application(Adw.Application):
                 success = True
             else:
                 success = self.__backup_manager.create_backup(
-                    iotas.config_manager.nextcloud_sync_configured(),
-                    iotas.config_manager.get_backup_note_extension(),
+                    self.__config_manager.nextcloud_sync_configured,
+                    self.__config_manager.backup_note_extension,
                 )
             self.quit()
             return int(not success)
@@ -197,7 +213,7 @@ class Application(Adw.Application):
                 success = False
             else:
                 success = self.__backup_manager.restore_backup(
-                    iotas.config_manager.nextcloud_sync_configured()
+                    self.__config_manager.nextcloud_sync_configured
                 )
             self.quit()
             return int(not success)
@@ -225,12 +241,12 @@ class Application(Adw.Application):
             self.activate_action("search-from-cli", term)
         elif "toggle-extended-preferences" in options:
             self.register()
-            if iotas.config_manager.get_show_extended_preferences():
+            if self.__config_manager.show_extended_preferences:
                 logging.info("Hiding extended preferences")
-                iotas.config_manager.set_show_extended_preferences(False)
+                self.__config_manager.show_extended_preferences = False
             else:
                 logging.info("Showing extended preferences")
-                iotas.config_manager.set_show_extended_preferences(True)
+                self.__config_manager.show_extended_preferences = True
             self.quit()
             return 0
 
@@ -241,11 +257,39 @@ class Application(Adw.Application):
         """Handle window activation."""
         if not self.__window:
             self.__create_window()
+            assert self.__window  # mypy
 
         self.__apply_css()
-        Application.apply_style()
+        self.apply_style()
         self.__window.present()
 
+    def __on_quit(self) -> None:
+        if self.__window:
+            self.__window.close()
+
+    def __on_create_note(self) -> None:
+        self.activate()
+        if self.__window:
+            self.__window.activate_action("win.create-note-from-cli")
+
+    def __on_create_note_from_uri(self, param: GObject.ParamSpec) -> None:
+        logging.info(isinstance(param, GObject.ParamSpec))
+        self.activate()
+        if self.__window:
+            self.__window.activate_action("win.create-note-from-uri", param),
+
+    def __on_open_note(self, param: GObject.ParamSpec) -> None:
+        logging.info(isinstance(param, GObject.ParamSpec))
+        self.activate()
+        if self.__window:
+            self.__window.activate_action("win.open-note", param),
+
+    def __on_search_from_cli(self, param: GObject.ParamSpec) -> None:
+        logging.info(isinstance(param, GObject.ParamSpec))
+        self.activate()
+        if self.__window:
+            self.__window.activate_action("win.search-from-cli", param),
+
     def __add_cli_options(self) -> None:
         self.add_main_option(
             "new-note",
@@ -355,54 +399,33 @@ class Application(Adw.Application):
             if shortcut is not None:
                 self.set_accels_for_action(f"app.{name}", [shortcut])
 
-        def on_create_note(action: Gio.SimpleAction, param: GLib.Variant) -> None:
-            self.activate()
-            if self.__window:
-                self.__window.activate_action("win.create-note-from-cli")
-
-        def on_create_note_from_uri(action: Gio.SimpleAction, param: GLib.Variant) -> None:
-            self.activate()
-            if self.__window:
-                self.__window.activate_action("win.create-note-from-uri", param),
-
-        def on_open_note(action: Gio.SimpleAction, param: GLib.Variant) -> None:
-            self.activate()
-            if self.__window:
-                self.__window.activate_action("win.open-note", param),
-
-        def on_search_from_cli(action: Gio.SimpleAction, param: GLib.Variant) -> None:
-            self.activate()
-            if self.__window:
-                self.__window.activate_action("win.search-from-cli", param),
-
         add_action("about", lambda _o, _p: self.__show_about_dialog())
-        add_action(
-            "quit",
-            lambda _o, _p: self.__window.close() if self.__window else None,
-            "<Control>q",
-        )
+        add_action("quit", lambda _o, _p: self.__on_quit(), "<Control>q")
         add_action("settings", lambda _o, _p: self.__show_preferences_dialog(), "<Control>comma")
         add_action(
             "shortcuts",
             lambda _o, _p: KeyboardShortcutsWindow(self.__window).present(),
             "<Control>question",
         )
-        add_action("create-note", on_create_note)
+        add_action(
+            "create-note",
+            lambda _o, _p: self.__on_create_note(),
+        )
         add_action(
             "create-note-from-uri",
-            on_create_note_from_uri,
+            lambda _o, param: self.__on_create_note_from_uri(param),
             None,
             GLib.VariantType("s"),
         )
         add_action(
             "open-note",
-            on_open_note,
+            lambda _o, param: self.__on_open_note(param),
             None,
             GLib.VariantType("u"),
         )
         add_action(
             "search-from-cli",
-            on_search_from_cli,
+            lambda _o, param: self.__on_search_from_cli(param),
             None,
             GLib.VariantType("s"),
         )
@@ -474,15 +497,15 @@ class Application(Adw.Application):
     def __create_backup(self) -> None:
         logging.info("Running remotely requested backup")
         self.__backup_manager.create_backup(
-            iotas.config_manager.nextcloud_sync_configured(),
-            iotas.config_manager.get_backup_note_extension(),
+            self.__config_manager.nextcloud_sync_configured,
+            self.__config_manager.backup_note_extension,
         )
 
     def __apply_index_category_label_css(self) -> None:
         # First pass approach to building this is using a display CSS provider, instead of adding
         # providers to each label. Presumably this is better, but it's a mess.
         style_manager = Adw.StyleManager.get_default()
-        category_style = iotas.config_manager.get_index_category_style()
+        category_style = self.__config_manager.index_category_style
         colour_names = {
             "blue": {"light": "blue_2", "dark": "blue_5"},
             "green": {"light": "green_4", "dark": "green_5"},
@@ -525,15 +548,3 @@ class Application(Adw.Application):
             self.__index_category_label_css_provider,
             Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION,
         )
-
-    @staticmethod
-    def apply_style() -> None:
-        """Apply style preference."""
-        manager = Adw.StyleManager.get_default()
-        style = iotas.config_manager.get_style()
-        if style == "dark":
-            manager.props.color_scheme = Adw.ColorScheme.FORCE_DARK
-        elif style == "light":
-            manager.props.color_scheme = Adw.ColorScheme.FORCE_LIGHT
-        else:
-            manager.props.color_scheme = Adw.ColorScheme.DEFAULT
