@@ -7,12 +7,16 @@ from typing import Optional
 
 from iotas.category import Category, CategorySpecialPurpose
 from iotas.category_manager import CategoryManager
-import iotas.config_manager
-from iotas import const
-from iotas.index_search_header_bar import IndexSearchState
+from iotas.config_manager import ConfigManager
+import iotas.const as const
+from iotas.first_start_page import FirstStartPage
+from iotas.index_menu_button import IndexMenuButton
+from iotas.index_note_list import IndexNoteList
+from iotas.index_search_header_bar import IndexSearchHeaderBar, IndexSearchState
 from iotas.note import Note
 from iotas.note_manager import NoteManager
 from iotas.selection_header_bar import SelectionHeaderBar
+from iotas.sidebar import Sidebar
 from iotas.sync_manager import SyncManager
 from iotas.theme_selector import ThemeSelector
 
@@ -28,57 +32,58 @@ class Index(Adw.BreakpointBin):
     }
 
     UNDO_NOTE_DELETION_DURATION = 5.0
-    SYNC_CONFLICT_NOTIFICATION_DURATION = 5.0
+    BUMPED_OUT_OF_EDITOR_NOTIFICATION_DURATION = 5.0
     SYNC_UPDATE_NOTIFICATION_DURATION = 2.0
     NOTES_APP_MISSING_NOTIFICATION_DURATION = 8.0
     BREAKPOINT_WIDTH = 700
 
-    _overlay_view = Gtk.Template.Child()
-    _breakpoint = Gtk.Template.Child()
+    _overlay_view: Adw.OverlaySplitView = Gtk.Template.Child()
+    _breakpoint: Adw.Breakpoint = Gtk.Template.Child()
 
-    _stack = Gtk.Template.Child()
-    _sidebar = Gtk.Template.Child()
-    _note_list_scroll = Gtk.Template.Child()
-    _note_list = Gtk.Template.Child()
-    _first_start = Gtk.Template.Child()
-    _loading = Gtk.Template.Child()
-    _empty = Gtk.Template.Child()
-    _search_info = Gtk.Template.Child()
-    _search_empty = Gtk.Template.Child()
+    _stack: Gtk.Stack = Gtk.Template.Child()
+    _sidebar: Sidebar = Gtk.Template.Child()
+    _note_list_scroll: Gtk.ScrolledWindow = Gtk.Template.Child()
+    _note_list: IndexNoteList = Gtk.Template.Child()
+    _first_start: FirstStartPage = Gtk.Template.Child()
+    _loading: Adw.StatusPage = Gtk.Template.Child()
+    _empty: Adw.StatusPage = Gtk.Template.Child()
+    _search_info: Adw.StatusPage = Gtk.Template.Child()
+    _search_empty: Adw.StatusPage = Gtk.Template.Child()
 
-    _header_stack = Gtk.Template.Child()
-    _main_header_bar = Gtk.Template.Child()
-    _content_sidebar_button = Gtk.Template.Child()
-    _search_header_bar = Gtk.Template.Child()
-    _selection_header_bar = Gtk.Template.Child()
-    _title = Gtk.Template.Child()
+    _header_stack: Gtk.Stack = Gtk.Template.Child()
+    _main_header_bar: Adw.HeaderBar = Gtk.Template.Child()
+    _content_sidebar_button: Gtk.Button = Gtk.Template.Child()
+    _search_header_bar: IndexSearchHeaderBar = Gtk.Template.Child()
+    _selection_header_bar: SelectionHeaderBar = Gtk.Template.Child()
+    _title: Gtk.Label = Gtk.Template.Child()
 
-    _toast_overlay = Gtk.Template.Child()
+    _toast_overlay: Adw.ToastOverlay = Gtk.Template.Child()
 
-    _menu_button = Gtk.Template.Child()
-    _new_button = Gtk.Template.Child()
+    _menu_button: IndexMenuButton = Gtk.Template.Child()
+    _new_button: Gtk.Button = Gtk.Template.Child()
 
-    _misc_banner = Gtk.Template.Child()
-    _offline_banner = Gtk.Template.Child()
-    _app_id_change_reauthenticate_banner = Gtk.Template.Child()
-    _generic_reauthenticate_banner = Gtk.Template.Child()
+    _misc_banner: Adw.Banner = Gtk.Template.Child()
+    _offline_banner: Adw.Banner = Gtk.Template.Child()
+    _app_id_change_reauthenticate_banner: Adw.Banner = Gtk.Template.Child()
+    _generic_reauthenticate_banner: Adw.Banner = Gtk.Template.Child()
 
     def __init__(self) -> None:
         super().__init__()
 
-        self.__note_manager = None
-        self.__category_manager = None
-        self.__sync_manager = None
+        self.__note_manager: NoteManager
+        self.__category_manager: CategoryManager
+        self.__sync_manager: SyncManager
+        self.__config_manager = ConfigManager.get_default()
 
         self.__active = False
-        self.__add_fav_action = None
-        self.__remove_fav_action = None
         self.__initialised = False
         self.__import_syncing = False
-        self.__search_after_init = None
+        self.__search_after_init: Optional[str] = None
         self.__searching_before_selection = False
-        self.__cancel_action = None
-        self.__syncing_toast = None
+        self.__add_fav_action: Gio.SimpleAction
+        self.__remove_fav_action: Gio.SimpleAction
+        self.__cancel_action: Gio.SimpleAction
+        self.__syncing_toast: Optional[Adw.Toast] = None
 
         self.__search_model = None
 
@@ -110,14 +115,14 @@ class Index(Adw.BreakpointBin):
 
         self._search_header_bar.connect("changed", lambda _o: self.__apply_search())
 
-        iotas.config_manager.settings.connect(
-            f"changed::{iotas.config_manager.INDEX_CATEGORY_STYLE}",
-            lambda _o, _k: self._note_list.update_category_labels(self.__category),
+        self.__config_manager.connect_changed(
+            ConfigManager.INDEX_CATEGORY_STYLE,
+            lambda: self._note_list.update_category_labels(self.__category),
         )
 
-        iotas.config_manager.settings.connect(
-            f"changed::{iotas.config_manager.PERSIST_SIDEBAR}",
-            lambda _o, _k: self.__update_for_sidebar_pin_change(),
+        self.__config_manager.connect_changed(
+            ConfigManager.PERSIST_SIDEBAR,
+            self.__update_for_sidebar_pin_change,
         )
 
         self._breakpoint.connect("apply", self.__on_breakpoint_apply)
@@ -168,7 +173,7 @@ class Index(Adw.BreakpointBin):
             "active", self._note_list, "searching", GObject.BindingFlags.SYNC_CREATE
         )
 
-        if iotas.config_manager.get_first_start():
+        if self.__config_manager.first_start:
             self._stack.set_visible_child(self._first_start)
             self._first_start.initialise_device()
         else:
@@ -242,7 +247,14 @@ class Index(Adw.BreakpointBin):
         """Let the user know a sync conflict has occurred with the note being edited."""
         # Translators: Description, notification
         toast = Adw.Toast.new(_("Sync conflict with note being edited"))
-        toast.set_timeout(self.SYNC_CONFLICT_NOTIFICATION_DURATION)
+        toast.set_timeout(self.BUMPED_OUT_OF_EDITOR_NOTIFICATION_DURATION)
+        self._toast_overlay.add_toast(toast)
+
+    def show_editing_note_deleted_alert(self) -> None:
+        """Let the user know the note being edited was remotely deleted."""
+        # Translators: Description, notification
+        toast = Adw.Toast.new(_("The note being edited was remotely deleted"))
+        toast.set_timeout(self.BUMPED_OUT_OF_EDITOR_NOTIFICATION_DURATION)
         self._toast_overlay.add_toast(toast)
 
     def show_secret_service_failure_alert(self) -> None:
@@ -288,7 +300,7 @@ class Index(Adw.BreakpointBin):
         return self.__active
 
     @active.setter
-    def active(self, value: bool) -> None:
+    def set_active(self, value: bool) -> None:
         self.__active = value
         self.__enable_actions(value)
 
@@ -366,7 +378,9 @@ class Index(Adw.BreakpointBin):
         action = Gio.SimpleAction.new("reset-filters")
         action.connect("activate", lambda _a, _p: self.__cancel_out_of_context(True))
         action_group.add_action(action)
-        app.set_accels_for_action("index.reset-filters", ["<Control>BackSpace", "<Control>Delete"])
+        app.set_accels_for_action(
+            "index.reset-filters", ["<Control><Shift>BackSpace", "<Control><Shift>Delete"]
+        )
 
         action = Gio.SimpleAction.new("selection-toggle-favourite")
         action.connect("activate", lambda _a, _p: self.__on_toggle_favourite())
@@ -476,7 +490,7 @@ class Index(Adw.BreakpointBin):
             self._generic_reauthenticate_banner.set_revealed(False)
 
     def __on_sync_started(self, _obj: GObject.Object) -> None:
-        if self.active and iotas.config_manager.get_show_syncing_debug_notification():
+        if self.active and self.__config_manager.show_syncing_debug_notification:
             # Another toast misuse replacing a revealer notification. Debug only at least.
             # TODO in future look at replacing this with a (debug only) spinner.
 
@@ -493,7 +507,7 @@ class Index(Adw.BreakpointBin):
                 self.__syncing_toast.dismiss()
                 self.__syncing_toast = None
             if self.__import_syncing:
-                self.__on_category_activated(self.__category)
+                self.__on_category_activated(self.__category, close_sidebar=True)
                 self.__import_syncing = False
             elif changes > 0:
                 self.__invalidate_view(check_older_notes=False)
@@ -603,7 +617,7 @@ class Index(Adw.BreakpointBin):
         self.__update_header_buttons_for_state()
 
     def __on_breakpoint_unapply(self, _bp: Adw.Breakpoint) -> None:
-        if iotas.config_manager.get_pin_sidebar():
+        if self.__config_manager.pin_sidebar:
             self._overlay_view.set_pin_sidebar(True)
             self._overlay_view.set_collapsed(False)
             self._overlay_view.set_show_sidebar(True)
@@ -665,7 +679,7 @@ class Index(Adw.BreakpointBin):
             count = self.__note_manager.get_filtered_note_count(
                 self._note_list.older_notes_displayed
             )
-            if not iotas.config_manager.get_first_start():
+            if not self.__config_manager.first_start:
                 if count == 0:
                     self._stack.set_visible_child(self._empty)
                 elif self._stack.get_visible_child() in (
@@ -692,6 +706,7 @@ class Index(Adw.BreakpointBin):
         self._search_header_bar.enter(clear_text, False)
 
         all_category = self._sidebar.select_and_fetch_category(None, CategorySpecialPurpose.ALL)
+        assert all_category
         self.__category = all_category
 
         self.__set_search_visible(True)
@@ -772,7 +787,7 @@ class Index(Adw.BreakpointBin):
         self._note_list_scroll.get_vadjustment().set_value(0)
         self.__set_search_visible(False)
         # Could look at removing the category updating and filter invalidating parts of this call
-        self.__on_category_activated(self.__category)
+        self.__on_category_activated(self.__category, close_sidebar=True)
         if self.get_root().using_keyboard_navigation:
             if note is not None:
                 self._note_list.select_and_focus_note(note)
@@ -783,8 +798,8 @@ class Index(Adw.BreakpointBin):
             self._content_sidebar_button.grab_focus()
 
     def __update_enabled_actions(self, enable: bool) -> None:
-        for action in ("toggle-sidebar", "create-note", "enter-search", "select-notes"):
-            action = self.__action_group.lookup(action)
+        for action_name in ("toggle-sidebar", "create-note", "enter-search", "select-notes"):
+            action = self.__action_group.lookup(action_name)
             action.set_property("enabled", enable)
 
     def __load_older_notes_worker(self) -> None:
@@ -799,10 +814,7 @@ class Index(Adw.BreakpointBin):
                 self._stack.set_visible_child(self._note_list_scroll)
 
     def __on_initial_load_from_db_complete(self) -> None:
-        loaded_older = self.__invalidate_view(check_older_notes=True)
-        if loaded_older:
-            self._note_list.populate_older_notes(self.__note_manager.older_notes_model)
-
+        self.__invalidate_view(check_older_notes=True)
         self._note_list.refresh_section_visibility(self.__category)
         self._note_list.clear_selections()
 
@@ -837,7 +849,11 @@ class Index(Adw.BreakpointBin):
                 new_category = self._sidebar.select_and_fetch_category(
                     None, CategorySpecialPurpose.ALL
                 )
-            self.__on_category_activated(new_category)
+            # Largely form mypy
+            if not new_category:
+                logging.warning("Failed to find category?")
+                return False
+            self.__on_category_activated(new_category, close_sidebar=True)
             return True
 
         return False
@@ -865,7 +881,7 @@ class Index(Adw.BreakpointBin):
                     CategorySpecialPurpose.ALL
                 )
                 # close_sidebar is False as we're closing it below
-                self.__on_category_activated(category, False)
+                self.__on_category_activated(category, close_sidebar=False)
         closed_the_sidebar = self.__close_sidebar()
         if not closed_the_sidebar:
             if self.__selecting():
@@ -874,7 +890,7 @@ class Index(Adw.BreakpointBin):
                 self.__end_search()
 
     def __close_sidebar(self) -> bool:
-        if iotas.config_manager.get_pin_sidebar() and self.get_width() >= self.BREAKPOINT_WIDTH:
+        if self.__config_manager.pin_sidebar and self.get_width() >= self.BREAKPOINT_WIDTH:
             return False
         elif not self._overlay_view.get_show_sidebar():
             return False
@@ -886,7 +902,7 @@ class Index(Adw.BreakpointBin):
         return True
 
     def __toggle_sidebar(self) -> None:
-        if iotas.config_manager.get_pin_sidebar() and self.get_width() >= self.BREAKPOINT_WIDTH:
+        if self.__config_manager.pin_sidebar and self.get_width() >= self.BREAKPOINT_WIDTH:
             # Pinned sidebar is open, let's just throw the focus around
             if self._sidebar.has_focus_within():
                 self.get_root().using_keyboard_navigation = True
@@ -906,7 +922,7 @@ class Index(Adw.BreakpointBin):
         if width == -1:
             width = self.get_width()
         if width >= self.BREAKPOINT_WIDTH:
-            pin = iotas.config_manager.get_pin_sidebar()
+            pin = self.__config_manager.pin_sidebar
             self._overlay_view.set_pin_sidebar(pin)
             self._overlay_view.set_show_sidebar(pin)
             self._overlay_view.set_collapsed(not pin)
@@ -922,7 +938,7 @@ class Index(Adw.BreakpointBin):
             # Used during initialisation
             if width == 0:
                 width = self.get_property("width-request")
-        if width >= self.BREAKPOINT_WIDTH and iotas.config_manager.get_pin_sidebar():
+        if width >= self.BREAKPOINT_WIDTH and self.__config_manager.pin_sidebar:
             show_sidebar_close = False
             show_content_sidebar_button = False
             show_sidebar_menu = True
