@@ -5,25 +5,28 @@ from gi.repository import Gdk, GObject, GLib, Gtk, Secret
 
 import datetime
 from email.utils import parsedate_to_datetime
+from enum import IntEnum, auto
 from json.decoder import JSONDecodeError
 import logging
 import os
 import requests
 from threading import Thread
-from typing import Optional, Tuple
+from typing import Optional
 from ssl import SSLCertVerificationError
 
-from iotas import const
+import iotas.const as const
+
 from iotas.nextcloud_sync_worker_configuration import NextcloudSyncWorkerConfiguration
 from iotas.note import Note
 from iotas.sync_result import SyncResult, ContentPushSyncResult
 
 
-class LoginRequestResult:
-    SUCCESS = 0
-    FAILURE_GENERIC = 1
-    FAILURE_SELF_SIGNED_SSL = 2
-    FAILURE_CERTIFICATE = 3
+class LoginRequestResult(IntEnum):
+
+    SUCCESS = auto()
+    FAILURE_GENERIC = auto()
+    FAILURE_SELF_SIGNED_SSL = auto()
+    FAILURE_CERTIFICATE = auto()
 
 
 class NextcloudSyncWorker(GObject.Object):
@@ -59,22 +62,25 @@ class NextcloudSyncWorker(GObject.Object):
     def __init__(self, config_manager: NextcloudSyncWorkerConfiguration) -> None:
         super().__init__()
         self.__config_manager = config_manager
-        self.__app_password = None
+        self.__app_password: Optional[str] = None
         self.__secret_service_failed = False
         self.authenticated = False
         self.__timeout = 10
 
-        self.__server = self.__config_manager.get_nextcloud_endpoint()
-        self.__username = self.__config_manager.get_nextcloud_username()
-        self.__prune_threshold = self.__config_manager.get_nextcloud_prune_threshold()
+        self.__server = self.__config_manager.nextcloud_endpoint
+        self.__username = self.__config_manager.nextcloud_username
+        self.__prune_threshold = self.__config_manager.nextcloud_prune_threshold
 
         if os.path.exists(self.CA_CHAIN_FILE):
             logging.info("Using SSL CA chain file at {}".format(self.CA_CHAIN_FILE))
-            self.verify = self.CA_CHAIN_FILE
+            self.verify: str | bool = self.CA_CHAIN_FILE
         else:
             self.verify = True
 
-        self.__headers = {"User-Agent": self.USER_AGENT}
+        self.__headers = {
+            "User-Agent": self.USER_AGENT,
+            "Cache-Control": "no-cache",
+        }
 
     def init_auth(self) -> None:
         """Initialise Nextcloud authentication details from the Secret Service."""
@@ -84,14 +90,14 @@ class NextcloudSyncWorker(GObject.Object):
 
     def start_login(
         self, server_uri: str, window: Gtk.Window
-    ) -> Tuple[LoginRequestResult, Optional[str], Optional[str]]:
+    ) -> tuple[LoginRequestResult, Optional[str], Optional[str]]:
         """Initiate a new login.
 
         :param str server_uri: Server instance URI
         :param Gtk.Window window: Main window
-        :return: Tuple with LoginRequestResult before endpoint URI and auth token (or Nones on
+        :return: tuple with LoginRequestResult before endpoint URI and auth token (or Nones on
             failures)
-        :rtype: Tuple[LoginRequestResult, Optional[str], Optional[str]]
+        :rtype: tuple[LoginRequestResult, Optional[str], Optional[str]]
         """
         uri = "{}{}".format(server_uri, self.LOGIN_ENDPOINT)
         try:
@@ -133,19 +139,20 @@ class NextcloudSyncWorker(GObject.Object):
             logging.warning("Failed to decode login request to JSON: {} for {}".format(e, res.text))
             return (LoginRequestResult.FAILURE_GENERIC, None, None)
 
+        # TODO change this to not need the window passed in
         def open_url_in_browser(window: Gtk.Window, response: dict) -> None:
             Gtk.show_uri(window, response["login"], Gdk.CURRENT_TIME)
 
         GLib.idle_add(open_url_in_browser, window, response)
         return (LoginRequestResult.SUCCESS, response["poll"]["endpoint"], response["poll"]["token"])
 
-    def check_endpoint_for_auth_token(self, endpoint: str, token: str) -> Tuple[bool, bool]:
+    def check_endpoint_for_auth_token(self, endpoint: str, token: str) -> tuple[bool, bool]:
         """Poll endpoint for authorisation success.
 
         :param str endpoint: Endpoint URI
         :param str token: Request token
         :return: Whether authenticated and whether auth. storage succeeded
-        :rtype: Tuple[bool, bool]
+        :rtype: tuple[bool, bool]
         """
         data = {"token": token}
         try:
@@ -182,6 +189,8 @@ class NextcloudSyncWorker(GObject.Object):
 
     def check_capabilities(self) -> None:
         """Check server API version."""
+        assert self.__username is not None
+        assert self.__app_password is not None
         url = self.__server + "/" + self.CAPABILITIES_ENDPOINT
         headers = self.__headers.copy()
         headers["OCS-APIRequest"] = "true"
@@ -271,9 +280,10 @@ class NextcloudSyncWorker(GObject.Object):
         ret = SyncResult.from_requests_response(res)
         if not ret.success:
             return ret
-        if "Last-Modified" in res.headers:
+        if res and "Last-Modified" in res.headers:
             dt = parsedate_to_datetime(res.headers["Last-Modified"])
             self.__prune_threshold = int(dt.timestamp())
+
         return ret
 
     def update_note(self, note: Note) -> ContentPushSyncResult:
@@ -323,14 +333,14 @@ class NextcloudSyncWorker(GObject.Object):
     def reset_prune_threshold(self) -> None:
         """Reset the sync threshold."""
         self.__prune_threshold = 0
-        self.__config_manager.set_nextcloud_prune_threshold(self.__prune_threshold)
+        self.__config_manager.nextcloud_prune_threshold = self.__prune_threshold
 
     @GObject.Property(type=str)
     def server(self) -> str:
         return self.__server
 
     @server.setter
-    def server(self, value: str) -> None:
+    def set_server(self, value: str) -> None:
         value = value.strip()
         value = GLib.uri_escape_string(value, None, True)
         value = value.strip("/")
@@ -341,7 +351,7 @@ class NextcloudSyncWorker(GObject.Object):
         return self.__authenticated
 
     @authenticated.setter
-    def authenticated(self, value: bool) -> None:
+    def set_authenticated(self, value: bool) -> None:
         self.__authenticated = value
 
     @GObject.Property(type=int)
@@ -357,7 +367,7 @@ class NextcloudSyncWorker(GObject.Object):
         return self.__timeout
 
     @timeout.setter
-    def timeout(self, value: int) -> None:
+    def set_timeout(self, value: int) -> None:
         self.__timeout = value
 
     def __init_secrets(self) -> None:
@@ -385,8 +395,8 @@ class NextcloudSyncWorker(GObject.Object):
         self.__server = endpoint
         self.__username = username
         self.__app_password = app_password
-        self.__config_manager.set_nextcloud_endpoint(self.__server)
-        self.__config_manager.set_nextcloud_username(self.__username)
+        self.__config_manager.nextcloud_endpoint = self.__server
+        self.__config_manager.nextcloud_username = self.__username
 
         self.reset_prune_threshold()
         self.authenticated = True
@@ -394,6 +404,8 @@ class NextcloudSyncWorker(GObject.Object):
         logging.debug("Nextcloud login successful")
 
     def __request_get(self, path: str, params: dict, timeout: float) -> Optional[requests.Response]:
+        assert self.__username is not None
+        assert self.__app_password is not None
         url = self.__get_url(path)
         try:
             return requests.get(
@@ -409,6 +421,8 @@ class NextcloudSyncWorker(GObject.Object):
             return None
 
     def __request_put(self, path: str, headers: dict, data: dict) -> Optional[requests.Response]:
+        assert self.__username is not None
+        assert self.__app_password is not None
         url = self.__get_url(path)
         try:
             return requests.put(
@@ -424,6 +438,8 @@ class NextcloudSyncWorker(GObject.Object):
             return None
 
     def __request_post(self, path: str, data: dict) -> Optional[requests.Response]:
+        assert self.__username is not None
+        assert self.__app_password is not None
         url = self.__get_url(path)
         try:
             return requests.post(
@@ -439,6 +455,8 @@ class NextcloudSyncWorker(GObject.Object):
             return None
 
     def __request_delete(self, path: str) -> Optional[requests.Response]:
+        assert self.__username is not None
+        assert self.__app_password is not None
         url = self.__get_url(path)
         try:
             return requests.delete(
