@@ -5,11 +5,11 @@ import json
 import logging
 from threading import Thread
 import time
-from typing import List, Optional
+from typing import Optional
 
 from iotas.category import Category
 from iotas.category_manager import CategoryManager
-import iotas.config_manager
+from iotas.config_manager import ConfigManager
 from iotas.note import Note, DirtyFields
 from iotas.note_database import NoteDatabase
 from iotas.note_list_model import (
@@ -52,16 +52,16 @@ class NoteManager(GObject.Object):
         self.__week_model = NoteListModelTimeFiltered(self.__category_filtered_model)
         self.__month_model = NoteListModelTimeFiltered(self.__category_filtered_model)
         self.__last_month_model = NoteListModelTimeFiltered(self.__category_filtered_model)
-        self.__older_notes_model = None
-        self.__search_model = None
+        self.__older_notes_model: Optional[NoteListModelTimeFiltered] = None
+        self.__search_model: Optional[NoteListModelSearch] = None
 
         self.__save_timeout_id = None
-        self.__deleted_notes = []
+        self.__deleted_notes: list[Note] = []
 
     def initiate_model_from_db(self) -> None:
         """Populate the models from the database."""
 
-        def add_to_model(notes: List[Note]) -> None:
+        def add_to_model(notes: list[Note]) -> None:
             start_time = time.time()
             self.add_notes_to_model(notes)
             logging.debug("Add to model took %.2fs", time.time() - start_time)
@@ -87,17 +87,17 @@ class NoteManager(GObject.Object):
         self.__search_model = NoteListModelSearch(self.__base_model)
         return self.__search_model
 
-    def add_notes_to_model(self, notes: List[Note]) -> None:
+    def add_notes_to_model(self, notes: list[Note]) -> None:
         """Add new notes to model.
 
-        :param List[Note] notes: The notes to add
+        :param list[Note] notes: The notes to add
         """
         self.__base_model.add_notes(notes)
 
-    def remove_notes_from_model(self, notes: List[Note]) -> None:
+    def remove_notes_from_model(self, notes: list[Note]) -> None:
         """Remove notes from the model.
 
-        :param List[Note] notes: The notes to remove
+        :param list[Note] notes: The notes to remove
         """
         self.__base_model.remove_notes(notes)
 
@@ -111,15 +111,16 @@ class NoteManager(GObject.Object):
         note.flag_changed()
         if current_category.special_purpose is None:
             note.category = current_category.name
-        if iotas.config_manager.get_first_start():
-            iotas.config_manager.set_first_start(False)
+        config_manager = ConfigManager.get_default()
+        if config_manager.first_start:
+            config_manager.first_start = False
         self.__category_manager.note_added(note.category)
         return note
 
-    def delete_notes(self, notes: List[Note]) -> None:
+    def delete_notes(self, notes: list[Note]) -> None:
         """Delete notes from the database and model.
 
-        :param List[Note] notes: The notes
+        :param list[Note] notes: The notes
         """
         self.__deleted_notes = []
         for note in notes:
@@ -254,10 +255,10 @@ class NoteManager(GObject.Object):
         thread.start()
         self.__category_manager.note_category_changed(old_category, note.category)
 
-    def set_and_persist_favourite_for_notes(self, notes: List[Note], value: bool) -> bool:
+    def set_and_persist_favourite_for_notes(self, notes: list[Note], value: bool) -> bool:
         """Set and persist the favourite flag on the provided notes.
 
-        :param List[Note] notes: The notes
+        :param list[Note] notes: The notes
         :param bool value: The new value
         :return: Whether any notes were updated
         :rtype: bool
@@ -272,14 +273,14 @@ class NoteManager(GObject.Object):
             self.__db.persist_note_favourite(note)
         return updates
 
-    def search_notes(self, term: str, restrict_to: List[int] = [], sort: bool = False) -> List[int]:
+    def search_notes(self, term: str, restrict_to: list[int] = [], sort: bool = False) -> list[int]:
         """Search database for notes with provided term.
 
         :param str term: The search term
-        :param List[int] restrict_to: List of ids of notes to restrict to
+        :param list[int] restrict_to: List of ids of notes to restrict to
         :param bool sort: Whether the results should be datetime sorted
         :return: A list of ids for any matching notes
-        :rtype: List[int]
+        :rtype: list[int]
         """
         return self.__db.search_notes(term, restrict_to, sort)
 
@@ -355,6 +356,7 @@ class NoteManager(GObject.Object):
             older_loaded = True
 
         if older_notes_displayed or older_loaded:
+            assert self.__older_notes_model is not None
             self.__older_notes_model.invalidate_filter(time_max=start_of_last_month)
 
         return older_loaded
@@ -367,18 +369,18 @@ class NoteManager(GObject.Object):
         start_of_last_month = NoteManager.get_start_of_last_month()
         self.__older_notes_model.invalidate_filter(time_max=start_of_last_month)
 
-    def get_deleted_notes_pending_undo(self) -> List[Note]:
+    def get_deleted_notes_pending_undo(self) -> list[Note]:
         """Fetch any notes queued for deletion.
 
         :return: The notes
-        :rtype: List[Note]
+        :rtype: list[Note]
         """
         return self.__deleted_notes
 
-    def set_deleted_notes_pending_undo(self, notes: List[Note]) -> None:
+    def set_deleted_notes_pending_undo(self, notes: list[Note]) -> None:
         """Set the notes queued for deletion.
 
-        :param List[Note] notes: The notes
+        :param list[Note] notes: The notes
         """
         self.__deleted_notes = notes
 
@@ -401,11 +403,11 @@ class NoteManager(GObject.Object):
         changed_fields.title = True
         self.__db.persist_note_selective(note, changed_fields)
 
-    def get_note_failed_pushes(self, note: Note) -> List[FailedPush]:
+    def get_note_failed_pushes(self, note: Note) -> list[FailedPush]:
         """Fetch any failed pushes for a note.
 
         :return: List of failed pushes
-        :rtype: List[FailedPush]
+        :rtype: list[FailedPush]
         """
         pushes_as_str = self.__db.get_note_failed_pushes(note)
         if not pushes_as_str:
@@ -473,11 +475,11 @@ class NoteManager(GObject.Object):
         return self.__last_month_model
 
     @GObject.Property(type=NoteListModelTimeFiltered, default=None)
-    def older_notes_model(self) -> NoteListModelTimeFiltered:
+    def older_notes_model(self) -> Optional[NoteListModelTimeFiltered]:
         return self.__older_notes_model
 
     @GObject.Property(type=NoteListModelSearch, default=None)
-    def search_model(self) -> NoteListModelSearch:
+    def search_model(self) -> Optional[NoteListModelSearch]:
         return self.__search_model
 
     def __persist_note_on_thread(self, note: Note) -> None:
@@ -521,7 +523,7 @@ class NoteManager(GObject.Object):
             self.__db.persist_note_editable(note)
 
     @staticmethod
-    def get_start_of_last_month() -> int:
+    def get_start_of_last_month() -> float:
         now = datetime.now()
         start_of_month_dt = now.replace(hour=0, minute=0, second=0, day=1)
         if start_of_month_dt.month > 1:
