@@ -8,7 +8,7 @@ import time
 from typing import Optional
 
 from iotas.category_manager import CategoryManager
-import iotas.config_manager
+from iotas.config_manager import ConfigManager
 from iotas.nextcloud_sync_worker import NextcloudSyncWorker, LoginRequestResult
 from iotas.note import Note
 from iotas.note_database import NoteDatabase
@@ -64,7 +64,8 @@ class SyncManager(GObject.Object):
     def __init__(self, db: NoteDatabase) -> None:
         super().__init__()
         self.__db = db
-        self.__sync_worker = NextcloudSyncWorker(iotas.config_manager)
+        self.__config_manager = ConfigManager.get_default()
+        self.__sync_worker = NextcloudSyncWorker(self.__config_manager)
         self.__lock = SyncWorkLock()
 
         self.__note_manager: NoteManager
@@ -78,14 +79,14 @@ class SyncManager(GObject.Object):
         self.__offline = False
         self.__sync_fail_counter = 0
 
-        iotas.config_manager.settings.connect(
-            f"changed::{iotas.config_manager.SYNC_INTERVAL}",
-            lambda _o, _k: self.__set_sync_interval(),
+        self.__config_manager.connect_changed(
+            ConfigManager.SYNC_INTERVAL,
+            self.__set_sync_interval,
         )
         self.__set_sync_interval()
 
-        iotas.config_manager.settings.bind(
-            iotas.config_manager.NETWORK_TIMEOUT,
+        self.__config_manager.bind(
+            ConfigManager.NETWORK_TIMEOUT,
             self.__sync_worker,
             "timeout",
             Gio.SettingsBindFlags.DEFAULT,
@@ -142,7 +143,7 @@ class SyncManager(GObject.Object):
 
     def close(self) -> None:
         """Close the manager, perform cleanup."""
-        iotas.config_manager.set_nextcloud_prune_threshold(self.__sync_worker.prune_threshold)
+        self.__config_manager.nextcloud_prune_threshold = self.__sync_worker.prune_threshold
 
     def reset_marker(self) -> None:
         """Reset the most recent sync timestamp market."""
@@ -196,8 +197,8 @@ class SyncManager(GObject.Object):
     @GObject.Property(type=bool, default=False)
     def configured_but_no_password(self) -> bool:
         return (
-            iotas.config_manager.get_nextcloud_endpoint() != ""
-            and iotas.config_manager.get_nextcloud_username() != ""
+            self.__config_manager.nextcloud_endpoint != ""
+            and self.__config_manager.nextcloud_username != ""
             and not self.authenticated
         )
 
@@ -210,7 +211,7 @@ class SyncManager(GObject.Object):
         self.__offline = new_val
 
     def __on_initial_note_load_complete(self) -> None:
-        if iotas.config_manager.get_nextcloud_username() != "":
+        if self.__config_manager.nextcloud_username != "":
             GLib.timeout_add(self.STARTUP_SYNC_INIT_DURATION, self.__perform_initial_sync)
 
     def __sync(self) -> None:
@@ -232,7 +233,7 @@ class SyncManager(GObject.Object):
         self.__sync_requested_while_active = False
 
         start_time = time.time()
-        fetching_all = iotas.config_manager.get_nextcloud_prune_threshold() == 0
+        fetching_all = self.__sync_worker.prune_threshold == 0
         sync_result = self.__sync_worker.get_notes()
         if sync_result.success:
             logging.debug("Server GET took {:.2f}s".format(time.time() - start_time))
@@ -556,15 +557,15 @@ class SyncManager(GObject.Object):
         thread.start()
 
     def __on_settings_fetched(self, _obj: GObject.Object, file_suffix: str) -> None:
-        if iotas.config_manager.get_backup_note_extension() != file_suffix:
+        if self.__config_manager.backup_note_extension != file_suffix:
             logging.info(
                 f"Changed backup note filename extension to '{file_suffix}' "
                 "as received from server"
             )
-            iotas.config_manager.set_backup_note_extension(file_suffix)
+            self.__config_manager.backup_note_extension = file_suffix
 
     def __set_sync_interval(self) -> None:
-        self.__sync_interval = iotas.config_manager.get_sync_interval()
+        self.__sync_interval = self.__config_manager.sync_interval
 
     def __api_check_and_settings_sync(self) -> None:
         # API check and settings sync are slung onto the back of the first request so that first
